==> vtk6-6.3.0-4-armv6h.pkg.tar.xz: vtk/vtkConnectivityFilter.java <==
// java wrapper for vtkConnectivityFilter object
//

package vtk;
import vtk.*;

public class vtkConnectivityFilter extends vtkUnstructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetScalarConnectivity_2(int id0);
  public void SetScalarConnectivity(int id0)
    { SetScalarConnectivity_2(id0); }

  private native int GetScalarConnectivity_3();
  public int GetScalarConnectivity()
    { return GetScalarConnectivity_3(); }

  private native void ScalarConnectivityOn_4();
  public void ScalarConnectivityOn()
    { ScalarConnectivityOn_4(); }

  private native void ScalarConnectivityOff_5();
  public void ScalarConnectivityOff()
    { ScalarConnectivityOff_5(); }

  private native void SetScalarRange_6(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_6(id0,id1); }

  private native void SetScalarRange_7(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_7(id0); }

  private native double[] GetScalarRange_8();
  public double[] GetScalarRange()
    { return GetScalarRange_8(); }

  private native void SetExtractionMode_9(int id0);
  public void SetExtractionMode(int id0)
    { SetExtractionMode_9(id0); }

  private native int GetExtractionModeMinValue_10();
  public int GetExtractionModeMinValue()
    { return GetExtractionModeMinValue_10(); }

  private native int GetExtractionModeMaxValue_11();
  public int GetExtractionModeMaxValue()
    { return GetExtractionModeMaxValue_11(); }

  private native int GetExtractionMode_12();
  public int GetExtractionMode()
    { return GetExtractionMode_12(); }

  private native void SetExtractionModeToPointSeededRegions_13();
  public void SetExtractionModeToPointSeededRegions()
    { SetExtractionModeToPointSeededRegions_13(); }

  private native void SetExtractionModeToCellSeededRegions_14();
  public void SetExtractionModeToCellSeededRegions()
    { SetExtractionModeToCellSeededRegions_14(); }

  private native void SetExtractionModeToLargestRegion_15();
  public void SetExtractionModeToLargestRegion()
    { SetExtractionModeToLargestRegion_15(); }

  private native void SetExtractionModeToSpecifiedRegions_16();
  public void SetExtractionModeToSpecifiedRegions()
    { SetExtractionModeToSpecifiedRegions_16(); }

  private native void SetExtractionModeToClosestPointRegion_17();
  public void SetExtractionModeToClosestPointRegion()
    { SetExtractionModeToClosestPointRegion_17(); }

  private native void SetExtractionModeToAllRegions_18();
  public void SetExtractionModeToAllRegions()
    { SetExtractionModeToAllRegions_18(); }

  private native String GetExtractionModeAsString_19();
  public String GetExtractionModeAsString()
    { return GetExtractionModeAsString_19(); }

  private native void InitializeSeedList_20();
  public void InitializeSeedList()
    { InitializeSeedList_20(); }

  private native void AddSeed_21(int id0);
  public void AddSeed(int id0)
    { AddSeed_21(id0); }

  private native void DeleteSeed_22(int id0);
  public void DeleteSeed(int id0)
    { DeleteSeed_22(id0); }

  private native void InitializeSpecifiedRegionList_23();
  public void InitializeSpecifiedRegionList()
    { InitializeSpecifiedRegionList_23(); }

  private native void AddSpecifiedRegion_24(int id0);
  public void AddSpecifiedRegion(int id0)
    { AddSpecifiedRegion_24(id0); }

  private native void DeleteSpecifiedRegion_25(int id0);
  public void DeleteSpecifiedRegion(int id0)
    { DeleteSpecifiedRegion_25(id0); }

  private native void SetClosestPoint_26(double id0,double id1,double id2);
  public void SetClosestPoint(double id0,double id1,double id2)
    { SetClosestPoint_26(id0,id1,id2); }

  private native void SetClosestPoint_27(double id0[]);
  public void SetClosestPoint(double id0[])
    { SetClosestPoint_27(id0); }

  private native double[] GetClosestPoint_28();
  public double[] GetClosestPoint()
    { return GetClosestPoint_28(); }

  private native int GetNumberOfExtractedRegions_29();
  public int GetNumberOfExtractedRegions()
    { return GetNumberOfExtractedRegions_29(); }

  private native void SetColorRegions_30(int id0);
  public void SetColorRegions(int id0)
    { SetColorRegions_30(id0); }

  private native int GetColorRegions_31();
  public int GetColorRegions()
    { return GetColorRegions_31(); }

  private native void ColorRegionsOn_32();
  public void ColorRegionsOn()
    { ColorRegionsOn_32(); }

  private native void ColorRegionsOff_33();
  public void ColorRegionsOff()
    { ColorRegionsOff_33(); }

  private native void SetOutputPointsPrecision_34(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_34(id0); }

  private native int GetOutputPointsPrecision_35();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_35(); }

  public vtkConnectivityFilter() { super(); }

  public vtkConnectivityFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkConnectivityFilter.java <==
// java wrapper for vtkConnectivityFilter object
//

package vtk;
import vtk.*;

public class vtkConnectivityFilter extends vtkUnstructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetScalarConnectivity_2(int id0);
  public void SetScalarConnectivity(int id0)
    { SetScalarConnectivity_2(id0); }

  private native int GetScalarConnectivity_3();
  public int GetScalarConnectivity()
    { return GetScalarConnectivity_3(); }

  private native void ScalarConnectivityOn_4();
  public void ScalarConnectivityOn()
    { ScalarConnectivityOn_4(); }

  private native void ScalarConnectivityOff_5();
  public void ScalarConnectivityOff()
    { ScalarConnectivityOff_5(); }

  private native void SetScalarRange_6(double id0,double id1);
  public void SetScalarRange(double id0,double id1)
    { SetScalarRange_6(id0,id1); }

  private native void SetScalarRange_7(double id0[]);
  public void SetScalarRange(double id0[])
    { SetScalarRange_7(id0); }

  private native double[] GetScalarRange_8();
  public double[] GetScalarRange()
    { return GetScalarRange_8(); }

  private native void SetExtractionMode_9(int id0);
  public void SetExtractionMode(int id0)
    { SetExtractionMode_9(id0); }

  private native int GetExtractionModeMinValue_10();
  public int GetExtractionModeMinValue()
    { return GetExtractionModeMinValue_10(); }

  private native int GetExtractionModeMaxValue_11();
  public int GetExtractionModeMaxValue()
    { return GetExtractionModeMaxValue_11(); }

  private native int GetExtractionMode_12();
  public int GetExtractionMode()
    { return GetExtractionMode_12(); }

  private native void SetExtractionModeToPointSeededRegions_13();
  public void SetExtractionModeToPointSeededRegions()
    { SetExtractionModeToPointSeededRegions_13(); }

  private native void SetExtractionModeToCellSeededRegions_14();
  public void SetExtractionModeToCellSeededRegions()
    { SetExtractionModeToCellSeededRegions_14(); }

  private native void SetExtractionModeToLargestRegion_15();
  public void SetExtractionModeToLargestRegion()
    { SetExtractionModeToLargestRegion_15(); }

  private native void SetExtractionModeToSpecifiedRegions_16();
  public void SetExtractionModeToSpecifiedRegions()
    { SetExtractionModeToSpecifiedRegions_16(); }

  private native void SetExtractionModeToClosestPointRegion_17();
  public void SetExtractionModeToClosestPointRegion()
    { SetExtractionModeToClosestPointRegion_17(); }

  private native void SetExtractionModeToAllRegions_18();
  public void SetExtractionModeToAllRegions()
    { SetExtractionModeToAllRegions_18(); }

  private native String GetExtractionModeAsString_19();
  public String GetExtractionModeAsString()
    { return GetExtractionModeAsString_19(); }

  private native void InitializeSeedList_20();
  public void InitializeSeedList()
    { InitializeSeedList_20(); }

  private native void AddSeed_21(int id0);
  public void AddSeed(int id0)
    { AddSeed_21(id0); }

  private native void DeleteSeed_22(int id0);
  public void DeleteSeed(int id0)
    { DeleteSeed_22(id0); }

  private native void InitializeSpecifiedRegionList_23();
  public void InitializeSpecifiedRegionList()
    { InitializeSpecifiedRegionList_23(); }

  private native void AddSpecifiedRegion_24(int id0);
  public void AddSpecifiedRegion(int id0)
    { AddSpecifiedRegion_24(id0); }

  private native void DeleteSpecifiedRegion_25(int id0);
  public void DeleteSpecifiedRegion(int id0)
    { DeleteSpecifiedRegion_25(id0); }

  private native void SetClosestPoint_26(double id0,double id1,double id2);
  public void SetClosestPoint(double id0,double id1,double id2)
    { SetClosestPoint_26(id0,id1,id2); }

  private native void SetClosestPoint_27(double id0[]);
  public void SetClosestPoint(double id0[])
    { SetClosestPoint_27(id0); }

  private native double[] GetClosestPoint_28();
  public double[] GetClosestPoint()
    { return GetClosestPoint_28(); }

  private native int GetNumberOfExtractedRegions_29();
  public int GetNumberOfExtractedRegions()
    { return GetNumberOfExtractedRegions_29(); }

  private native void SetColorRegions_30(int id0);
  public void SetColorRegions(int id0)
    { SetColorRegions_30(id0); }

  private native int GetColorRegions_31();
  public int GetColorRegions()
    { return GetColorRegions_31(); }

  private native void ColorRegionsOn_32();
  public void ColorRegionsOn()
    { ColorRegionsOn_32(); }

  private native void ColorRegionsOff_33();
  public void ColorRegionsOff()
    { ColorRegionsOff_33(); }

  private native void SetOutputPointsPrecision_34(int id0);
  public void SetOutputPointsPrecision(int id0)
    { SetOutputPointsPrecision_34(id0); }

  private native int GetOutputPointsPrecision_35();
  public int GetOutputPointsPrecision()
    { return GetOutputPointsPrecision_35(); }

  public vtkConnectivityFilter() { super(); }

  public vtkConnectivityFilter(long id) { super(id); }
  public native long   VTKInit();

}
